@@ -8,8 +8,9 @@ from pypuppetdb.errors import EmptyResponseError
 
 from flask import abort
 
+
 def jsonprint(value):
-  return json.dumps(value, indent=2, separators=(',', ': ') )
+    return json.dumps(value, indent=2, separators=(',', ': '))
 
 
 def get_or_abort(func, *args, **kwargs):
@@ -20,7 +21,7 @@ def get_or_abort(func, *args, **kwargs):
     """
     try:
         return func(*args, **kwargs)
-    except HTTPError, e:
+    except HTTPError as e:
         abort(e.response.status_code)
     except ConnectionError:
         abort(500)
@@ -28,13 +29,13 @@ def get_or_abort(func, *args, **kwargs):
         abort(204)
 
 
-def ten_reports(reports):
-    """Helper to yield the first then reports from the reports generator.
+def limit_reports(reports, limit):
+    """Helper to yield a number of from the reports generator.
 
     This is an ugly solution at best...
     """
     for count, report in enumerate(reports):
-        if count == 10:
+        if count == limit:
             raise StopIteration
         yield report
 
